==> php-embed_4.4.7.orig.tar.xz: php-embed-4.4.7/tests/fixtures/www.flickr.com.photos-desescribir.php <==
<?php
declare(strict_types = 1);

return [
    'authorName' => 'desescribir',
    'authorUrl' => 'https://www.flickr.com/photos/desescribir/',
    'cms' => null,
    'code' => [
        'html' => '<a data-flickr-embed=\'true\' href=\'https://www.flickr.com/photos/34912442@N03\' title=\'desescribir\'><img src=\'https://live.staticflickr.com/8765/17244790083_d2f40f713f_b.jpg\' width=\'800\' height=\'600\' alt=\'Cantos de berce\'></a><script async src=\'https://embedr.flickr.com/assets/client-code.js\' charset=\'utf-8\'></script>',
        'width' => 800,
        'height' => 600,
        'ratio' => 75.0
    ],
    'description' => 'Explore desescribir\'s 618 photos on Flickr!',
    'favicon' => 'https://combo.staticflickr.com/pw/favicon.ico',
    'feeds' => [
        'https://www.flickr.com/services/feeds/photos_public.gne?id=34912442@N03&lang=en-us&format=atom'
    ],
    'icon' => 'https://combo.staticflickr.com/pw/images/favicons/favicon-120.png',
    'image' => 'https://live.staticflickr.com/8765/17244790083_d2f40f713f_b.jpg',
    'keywords' => [],
    'language' => 'en-us',
    'languages' => [],
    'license' => 'https://creativecommons.org/licenses/by-nc-nd/2.0/',
    'providerName' => 'Flickr',
    'providerUrl' => 'https://www.flickr.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'desescribir',
    'url' => 'https://www.flickr.com/photos/desescribir/',
    'linkedData' => [
        [
            '@context' => 'http://schema.org',
            '@type' => 'WebSite',
            'name' => 'Flickr',
            'url' => 'https://www.flickr.com',
            'potentialAction' => [
                '@type' => 'SearchAction',
                'target' => 'https://www.flickr.com/search?text={search_term_string}&structured=yes',
                'query-input' => 'required name=search_term_string'
            ]
        ],
        [
            '@context' => 'http://schema.org',
            '@type' => 'Organization',
            'url' => 'http://www.flickr.com',
            'logo' => 'https://www.flickr.com/images/opensearch-flickr-logo.png'
        ],
        [
            '@context' => 'http://schema.org',
            '@type' => 'Person',
            'name' => 'Flickr',
            'url' => 'https://www.flickr.com',
            'sameAs' => [
                'https://www.facebook.com/flickr',
                'https://instagram.com/flickr',
                'https://flickr.tumblr.com',
                'https://twitter.com/flickr',
                'https://plus.google.com/+flickr',
                'https://www.pinterest.com/flickr'
            ]
        ]
    ],
    'oEmbed' => [
        'type' => 'rich',
        'flickr_type' => 'photostream',
        'title' => 'desescribir',
        'author_name' => 'desescribir',
        'author_url' => 'https://www.flickr.com/photos/desescribir/',
        'width' => 800,
        'height' => 600,
        'url' => 'https://www.flickr.com/photos/desescribir/',
        'web_page' => 'https://www.flickr.com/photos/desescribir/',
        'thumbnail_url' => 'https://live.staticflickr.com/8765/17244790083_d2f40f713f_b.jpg',
        'thumbnail_width' => 800,
        'thumbnail_height' => 600,
        'web_page_short_url' => 'https://flic.kr/ps/wRmwB',
        'license_url' => 'https://creativecommons.org/licenses/by-nc-nd/2.0/',
        'html' => '<a data-flickr-embed=\'true\' href=\'https://www.flickr.com/photos/34912442@N03\' title=\'desescribir\'><img src=\'https://live.staticflickr.com/8765/17244790083_d2f40f713f_b.jpg\' width=\'800\' height=\'600\' alt=\'Cantos de berce\'></a><script async src=\'https://embedr.flickr.com/assets/client-code.js\' charset=\'utf-8\'></script>',
        'version' => '1.0',
        'cache_age' => 3600,
        'provider_name' => 'Flickr',
        'provider_url' => 'https://www.flickr.com/'
    ]
];

==> php-embed_4.4.17.orig.tar.xz: php-embed-4.4.17/tests/fixtures/www.flickr.com.photos-desescribir.php <==
<?php
declare(strict_types = 1);

return [
    'authorName' => 'desescribir',
    'authorUrl' => 'https://www.flickr.com/photos/desescribir/',
    'cms' => null,
    'code' => [
        'html' => '<a data-flickr-embed=\'true\' href=\'https://www.flickr.com/photos/34912442@N03\' title=\'desescribir\'><img src=\'https://live.staticflickr.com/8765/17244790083_d2f40f713f_b.jpg\' width=\'800\' height=\'600\' alt=\'Cantos de berce\'></a><script async src=\'https://embedr.flickr.com/assets/client-code.js\' charset=\'utf-8\'></script>',
        'width' => 800,
        'height' => 600,
        'ratio' => 75.0
    ],
    'description' => 'Explore desescribir\'s 618 photos on Flickr!',
    'favicon' => 'https://combo.staticflickr.com/pw/favicon.ico',
    'feeds' => [
        'https://www.flickr.com/services/feeds/photos_public.gne?id=34912442@N03&lang=en-us&format=atom'
    ],
    'icon' => 'https://combo.staticflickr.com/pw/images/favicons/favicon-120.png',
    'image' => 'https://live.staticflickr.com/8765/17244790083_d2f40f713f_b.jpg',
    'keywords' => [],
    'language' => 'en-us',
    'languages' => [],
    'license' => 'https://creativecommons.org/licenses/by-nc-nd/2.0/',
    'providerName' => 'Flickr',
    'providerUrl' => 'https://www.flickr.com/',
    'publishedTime' => null,
    'redirect' => null,
    'title' => 'desescribir',
    'url' => 'https://www.flickr.com/photos/desescribir/',
    'linkedData' => [
        '@context' => 'http://schema.org',
        '@type' => 'WebSite',
        'name' => 'Flickr',
        'url' => 'https://www.flickr.com',
        'potentialAction' => [
            '@type' => 'SearchAction',
            'target' => 'https://www.flickr.com/search?text={search_term_string}&structured=yes',
            'query-input' => 'required name=search_term_string'
        ]
    ],
    'oEmbed' => [
        'type' => 'rich',
        'flickr_type' => 'photostream',
        'title' => 'desescribir',
        'author_name' => 'desescribir',
        'author_url' => 'https://www.flickr.com/photos/desescribir/',
        'width' => 800,
        'height' => 600,
        'url' => 'https://www.flickr.com/photos/desescribir/',
        'web_page' => 'https://www.flickr.com/photos/desescribir/',
        'thumbnail_url' => 'https://live.staticflickr.com/8765/17244790083_d2f40f713f_b.jpg',
        'thumbnail_width' => 800,
        'thumbnail_height' => 600,
        'web_page_short_url' => 'https://flic.kr/ps/wRmwB',
        'license_url' => 'https://creativecommons.org/licenses/by-nc-nd/2.0/',
        'html' => '<a data-flickr-embed=\'true\' href=\'https://www.flickr.com/photos/34912442@N03\' title=\'desescribir\'><img src=\'https://live.staticflickr.com/8765/17244790083_d2f40f713f_b.jpg\' width=\'800\' height=\'600\' alt=\'Cantos de berce\'></a><script async src=\'https://embedr.flickr.com/assets/client-code.js\' charset=\'utf-8\'></script>',
        'version' => '1.0',
        'cache_age' => 3600,
        'provider_name' => 'Flickr',
        'provider_url' => 'https://www.flickr.com/'
    ],
    'allLinkedData' => [
        [
            '@context' => 'http://schema.org',
            '@type' => 'WebSite',
            'name' => 'Flickr',
            'url' => 'https://www.flickr.com',
            'potentialAction' => [
                '@type' => 'SearchAction',
                'target' => 'https://www.flickr.com/search?text={search_term_string}&structured=yes',
                'query-input' => 'required name=search_term_string'
            ]
        ],
        [
            '@context' => 'http://schema.org',
            '@type' => 'Organization',
            'url' => 'http://www.flickr.com',
            'logo' => 'https://www.flickr.com/images/opensearch-flickr-logo.png'
        ],
        [
            '@context' => 'http://schema.org',
            '@type' => 'Person',
            'name' => 'Flickr',
            'url' => 'https://www.flickr.com',
            'sameAs' => [
                'https://www.facebook.com/flickr',
                'https://instagram.com/flickr',
                'https://flickr.tumblr.com',
                'https://twitter.com/flickr',
                'https://plus.google.com/+flickr',
                'https://www.pinterest.com/flickr'
            ]
        ],
        [
            '@context' => 'https://schema.org',
            '@type' => 'BlogPosting',
            'mainEntityOfPage' => [
                '@type' => 'WebPage',
                '@id' => 'https://www.flickr.com/photos/desescribir/'
            ],
            'headline' => 'desescribir',
            'image' => [
                '@type' => 'ImageObject',
                'url' => 'https://live.staticflickr.com/8765/17244790083_d2f40f713f_z.jpg',
                'height' => 454,
                'width' => 640
            ],
            'author' => [
                '@type' => 'Person',
                'name' => 'desescribir',
                'sameAs' => 'https://www.flickr.com/photos/desescribir/'
            ],
            'publisher' => [
                '@type' => 'Organization',
                'name' => 'Flickr',
                'logo' => [
                    '@type' => 'ImageObject',
                    'url' => 'https://www.flickr.com/images/opensearch-flickr-logo.png',
                    'width' => 64,
                    'height' => 64
                ]
            ],
            'description' => 'Explore desescribir\'s 618 photos on Flickr!'
        ]
    ]
];
